
'filesysobjects' - package
###########################

.. toctree::
   :maxdepth: 4

.. automodule:: filesysobjects.FileSysObjects
.. automodule:: filesysobjects.PySourceInfo

**Sources**

* `filesysobjects.FileSysObjects [source] <_modules/filesysobjects/FileSysObjects.html#>`_

* `filesysobjects.PySourceInfo [source] <_modules/filesysobjects/PySourceInfo.html#>`_


.. include:: filesysobjects.rst
.. include:: pysourceinfo.rst

